Name:		BEDTools
Version:	2.27.1
Release:	1%{?dist}
Summary:	A flexible suite of utilities for comparing genomic features
Group:		Applications/Engineering
License:	GPLv2+
URL:		https://github.com/arq5x/bedtools2
Source0:	https://github.com/arq5x/bedtools2/releases/download/v%{version}/bedtools-%{version}.tar.gz
#Fix debuginfo canonicalization error
Patch0:		BEDTools-double-parenthesis.patch
# Fix very bizarre mess in the sphinx config which breaks build:
# https://github.com/arq5x/bedtools2/pull/625
Patch1:		0001-Ditch-bizarre-inclusion-then-mock-out-of-matplotlib-.patch

BuildRequires:	  zlib-devel
BuildRequires:	  python2
BuildRequires:	  python2-sphinx

%description

The BEDTools utilities allow one to address common genomics tasks such
as finding feature overlaps and computing coverage. The utilities are
largely based on four widely-used file formats: BED, GFF/GTF, VCF, and
SAM/BAM. Using BEDTools, one can develop sophisticated pipelines that
answer complicated research questions by "streaming" several BEDTools
together. 

%prep
%autosetup -n bedtools2 -p1
# remove bundled curl library
rm -rf src/utils/curl


%build
# gzstream includes a local header file
make %{?_smp_mflags} CXXFLAGS="-I. %{optflags}" V=1
cd docs
make clean html
cd ..


%install
mkdir -p %{buildroot}%{_bindir}
install -m 0755 bin/* %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -a genomes/ %{buildroot}%{_datadir}/%{name}
cp -a data/ %{buildroot}%{_datadir}/%{name}
# fix permissions
find %{buildroot}%{_datadir}/%{name} -type f -exec chmod 0644 {} \;


%files
%doc README.md RELEASE_HISTORY docs/_build/html/
%license LICENSE
%dir %{_datadir}/%{name}
%{_bindir}/*
%{_datadir}/%{name}/genomes
%{_datadir}/%{name}/data

%changelog
* Wed Apr 11 2018 Filipe Rosset <rosset.filipe@gmail.com> - 2.27.1-1
- update to latest upstream release 2.27.1
- fixes rhbz #1555465 and rhbz #1526649
- spec cleanup

* Sat Mar 17 2018 Adam Huffman <bloch@verdurin.com> - 2.27.0-1
- Update to latest upstream release 2.27.0

* Wed Mar 14 2018 Iryna Shcherbina <ishcherb@redhat.com> - 2.26.0-8
- Update Python 2 dependency declarations to new packaging standards
  (See https://fedoraproject.org/wiki/FinalizingFedoraSwitchtoPython3)

* Wed Mar 07 2018 Adam Williamson <awilliam@redhat.com> - 2.26.0-7
- Rebuild to fix GCC 8 mis-compilation
  See https://da.gd/YJVwk ("GCC 8 ABI change on x86_64")

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.26.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.26.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.26.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.26.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Sat Aug 06 2016 Adam Huffman <bloch@verdurin.com> - 2.26.0-2
- Fix from Kyle Powell to re-enable debuginfo

* Sat Jul 09 2016 Adam Huffman <bloch@verdurin.com> - 2.26.0-1
- Update to latest upstream release 2.26.0

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.25.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Sep 05 2015 Adam Huffman <bloch@verdurin.com> - 2.25.0-1
- Update to latest upstream release 2.25.0
- Disable upstreamed patches
- Disable double path separator patch for now

* Sun Aug 23 2015 Adam Huffman <bloch@verdurin.com> - 2.24.0-6
- Fix binary directory path

* Sat Jul 18 2015 Adam Huffman <bloch@verdurin.com> - 2.24.0-5
- Re-enable 32-bit and ARM builds

* Fri Jul 17 2015 Adam Huffman <bloch@verdurin.com> - 2.24.0-4
- Add temporary patches to fix 32-bit compilation derived from upstream commits

* Sun Jul 12 2015 Adam Huffman <bloch@verdurin.com> - 2.24.0-3
- Disable i686 build until upstream fixes arrive

* Fri Jul  3 2015 Peter Robinson <pbrobinson@fedoraproject.org> 2.24.0-2
- Disable hardened build
- Exclude ARMv7 for the moment (tracked rhbz 1239119)

* Wed Jul 01 2015 Adam Huffman <bloch@verdurin.com> - 2.24.0-1
- Disable debuginfo for now to re-enable build
- Disable debuginfo-related patches for now

* Tue Jun 16 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.23.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Apr 06 2015 Adam Huffman <bloch@verdurin.com> - 2.23.0-2
- Simplify list of included binaries

* Mon Mar 09 2015 Adam Huffman <bloch@verdurin.com> - 2.23.0-1
- Update to upstream 2.23.0

* Sat Dec 27 2014 Adam Huffman <bloch@verdurin.com> - 2.22.0-1
- Update to upstream 2.22.0

* Mon Aug 25 2014 Adam Huffman <bloch@verdurin.com> - 2.20.1-4
- Update debugedit patch
- Reinstate gzstream patch

* Fri Aug 15 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.20.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 14 2014 Adam Huffman <bloch@verdurin.com> - 2.20.1-2
- More path changes to fix debuginfo build

* Sat Jun 07 2014 Adam Huffman <bloch@verdurin.com> - 2.20.1-1
- Update to upstream 2.20.1
- Build integrated docs and remove obsolete PDF manual in -docs subpackage

* Fri Jun 06 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.19.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed Apr 16 2014 Adam Huffman <bloch@verdurin.com> - 2.19.1-2
- Fix for debugedit canonicalization error
- Don't include jaccard, reldist and sample

* Wed Apr 16 2014 Adam Huffman <bloch@verdurin.com> - 2.19.1-1
- Update to upstream 2.19.1 release

* Sun Mar 02 2014 Adam Huffman <bloch@verdurin.com> - 2.19.0-1
- Update to upstream 2.19.0 release
- Upstream now hosted at Github, not Google Code
- Add three new tools

* Tue Aug 06 2013 Adam Huffman <bloch@verdurin.com> - 2.17.0-1
- Update to upstream 2.17.0 release
- Fix changed tarball directory name
- Add four new tools

* Fri Aug 02 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.15.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Feb 13 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.15.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.15.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Tue Feb 28 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.15.0-3
- Rebuilt for c++ ABI breakage

* Thu Jan 12 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.15.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Jan  4 2012 Adam Huffman <verdurin@fedoraproject.org> - 2.15.0-1
- update to new upstream release 2.15.0
- new unified command line interface 'bedtools'
- add python BR for new Makefile target to generate legacy commands
- remove 'overlap'
- add 'bedpeToBam', 'clusterBed', 'getOverlap', 'groupBy'
- add 'multiIntersectBed', 'windowMaker'

* Fri Oct 28 2011 Adam Huffman <bloch@verdurin.com> - 2.13.4-1
- new upstream minor bugfix release, see http://code.google.com/p/bedtools/

* Thu Sep  8 2011 Adam Huffman <bloch@verdurin.com> - 2.13.1-1
- new upstream minor release including fixes for tagBam

* Tue Sep  6 2011 Adam Huffman <bloch@verdurin.com> - 2.13.0-1
- new upstream release 2.13.0
- new tools tagBam and nucBed

* Tue Apr 12 2011 Adam Huffman <bloch@verdurin.com> - 2.12.0-1
- new upstream release 2.12.0
- new tools cuffToTrans and flankBed

* Thu Feb 17 2011 Adam Huffman <bloch@verdurin.com> - 2.11.2-1
- new upstream release
- now README.rst
- remove groupBy command, now in filo
- new fjoin command

* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.10.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Nov 17 2010 Adam Huffman <bloch@verdurin.com> - 2.10.1-1
- new annotateBed tool
- updated manual

* Sun Sep 12 2010 Adam Huffman <bloch@verdurin.com> - 2.9.0-5
- add license for -docs 

* Wed Sep  1 2010 Adam Huffman <bloch@verdurin.com> - 2.9.0-4
- add -docs subpackage including PDF manual

* Tue Aug 31 2010 Adam Huffman <bloch@verdurin.com> - 2.9.0-3
- remove 'curl' library properly

* Tue Aug 31 2010 Adam Huffman <bloch@verdurin.com> - 2.9.0-2
- fix license and add LICENSE file
- fix permissions of data/
- remove bundled 'curl' library

* Wed Aug 25 2010 Adam Huffman <bloch@verdurin.com> - 2.9.0-1
- new upstream release
- add new unionBedGraphs tool

* Mon Aug  2 2010 Adam Huffman <bloch@verdurin.com> - 2.8.3-1
- initial version
- override upstream CFLAGS
- allow including gzstream header file
